pub fn a() -> ABuilderExpand description
The HTML <a> element (or anchor element), along with its href attribute, creates
a hyperlink to other web pages, files, locations within the same page, email addresses, or
any other URL.
pub fn a() -> ABuilderThe HTML <a> element (or anchor element), along with its href attribute, creates
a hyperlink to other web pages, files, locations within the same page, email addresses, or
any other URL.