pub fn dd() -> DdBuilderExpand description
The HTML <dd> element provides the description, definition, or value for the
preceding term (<dt>) in a description list (<dl>).
pub fn dd() -> DdBuilderThe HTML <dd> element provides the description, definition, or value for the
preceding term (<dt>) in a description list (<dl>).