pub fn div() -> DivBuilderExpand description
The HTML Content Division element (<div>) is the generic container for flow
content. It has no effect on the content or layout until styled using CSS.
pub fn div() -> DivBuilderThe HTML Content Division element (<div>) is the generic container for flow
content. It has no effect on the content or layout until styled using CSS.