tr

Function tr 

pub fn tr() -> TrBuilder
The HTML <tr> element defines a row of cells in a table. The row’s cells can then be established using a mix of <td> (data cell) and <th> (header cell) elements.