pub fn br() -> BrBuilderExpand description
The HTML <br> element produces a line break in text (carriage-return). It is useful
for writing a poem or an address, where the division of lines is significant.
pub fn br() -> BrBuilderThe HTML <br> element produces a line break in text (carriage-return). It is useful
for writing a poem or an address, where the division of lines is significant.