pub fn tr() -> TrBuilderExpand description
The HTML <tr> element defines a row of cells in a table. The row’s cells can then
be established using a mix of <td> (data cell) and <th> (header cell)
elements.
pub fn tr() -> TrBuilderThe HTML <tr> element defines a row of cells in a table. The row’s cells can then
be established using a mix of <td> (data cell) and <th> (header cell)
elements.